/*
			Print Window Callbacks
 */

#ifndef PRINTWINCB_H
#define PRINTWINCB_H

#include <sys/types.h>
#include <gtk/gtk.h>
#include "printwin.h"


extern void PrintWinSourceTypeTextInsertCB(
	GtkEditable *editable,
	const gchar *text, gint length, gint *position,
	gpointer data
);
extern void PrintWinPrintToToggleCB(GtkWidget *widget, gpointer data);
extern void PrintWinPrintFileBrowseCB(GtkWidget *widget, gpointer data);
extern void PrintWinOrientationToggleCB(GtkWidget *widget, gpointer data);
extern void PrintWinVisualToggleCB(GtkWidget *widget, gpointer data);
extern void PrintWinPaperSizeToggleCB(GtkWidget *widget, gpointer data); 

extern gint PrintWinEventCB(
	GtkWidget *widget, gpointer event, gpointer data
);
extern gint PrintWinPreviewEventCB(
	GtkWidget *widget, gpointer event, gpointer data
);
extern void PrintWinDestroyCB(GtkObject *object, gpointer data);
extern gint PrintWinCloseCB(
	GtkWidget *widget, GdkEvent *event, gpointer data
);

extern void PrintWinPreviewCenterCB(GtkWidget *widget, gpointer data);
extern void PrintWinPreviewOriginalSizeCB(GtkWidget *widget, gpointer data);
extern void PrintWinPreviewSizeToFitCB(GtkWidget *widget, gpointer data);

extern void PrintWinPrintButtonCB(GtkWidget *widget, gpointer data);
extern void PrintWinCancelButtonCB(GtkWidget *widget, gpointer data);

#endif	/* PRINTWINCB_H */
